@@ -26,28 +26,28 @@
 static const R_CallMethodDef CallEntries[] = {
 	CALLDEF(anyNA_text, 1),
 	CALLDEF(as_character_text, 1),
-	CALLDEF(as_integer_dataset, 1),
-	CALLDEF(as_double_dataset, 1),
-	CALLDEF(as_list_dataset, 1),
-	CALLDEF(as_logical_dataset, 1),
-	CALLDEF(as_text_dataset, 1),
-	CALLDEF(coerce_text, 1),
-	CALLDEF(datatype_dataset, 1),
-	CALLDEF(datatypes_dataset, 1),
-	CALLDEF(dim_dataset, 1),
+	CALLDEF(as_integer_jsondata, 1),
+	CALLDEF(as_double_jsondata, 1),
+	CALLDEF(as_list_jsondata, 1),
+	CALLDEF(as_logical_jsondata, 1),
+	CALLDEF(as_text_character, 1),
+	CALLDEF(as_text_jsondata, 1),
+	CALLDEF(datatype_jsondata, 1),
+	CALLDEF(datatypes_jsondata, 1),
+	CALLDEF(dim_jsondata, 1),
 	CALLDEF(is_na_text, 1),
-	CALLDEF(length_dataset, 1),
+	CALLDEF(length_jsondata, 1),
 	CALLDEF(length_text, 1),
 	CALLDEF(logging_off, 0),
 	CALLDEF(logging_on, 0),
-	CALLDEF(names_dataset, 1),
-	CALLDEF(print_dataset, 1),
-	CALLDEF(read_json, 1),
+	CALLDEF(names_jsondata, 1),
+	CALLDEF(print_jsondata, 1),
+	CALLDEF(read_ndjson, 1),
 	CALLDEF(sentences_text, 1),
-	CALLDEF(simplify_dataset, 1),
-	CALLDEF(subscript_dataset, 2),
-	CALLDEF(subset_dataset, 3),
-	CALLDEF(subset_text, 2),
+	CALLDEF(simplify_jsondata, 1),
+	CALLDEF(subscript_jsondata, 2),
+	CALLDEF(subset_jsondata, 3),
+	CALLDEF(subset_text_handle, 2),
 	CALLDEF(tokens_text, 2),
 	CALLDEF(word_counts_text, 2),
         {NULL, NULL, 0}
